==> radiance-substance-3.5.0-sources.jar: org/pushingpixels/substance/api/skin/SkinInfo.java <==
/*
 * Copyright (c) 2005-2020 Radiance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of the copyright holder nor the names of
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.pushingpixels.substance.api.skin;

import org.pushingpixels.substance.internal.utils.TraitInfoImpl;

/**
 * Information on a single skin. This class is part of officially supported API.
 * 
 * @author Kirill Grouchnikov
 */
public class SkinInfo extends TraitInfoImpl {
	/**
	 * Simple constructor.
	 * 
	 * @param skinDisplayName
	 *            Display name of <code>this</code> skin.
	 * @param skinClassNameResolver
	 *            Class name resolver of <code>this</code> skin.
	 */
	public SkinInfo(String skinDisplayName, LazyClassNameResolver skinClassNameResolver) {
		super(skinDisplayName, skinClassNameResolver);
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof SkinInfo) {
			return this.getDisplayName().equals(((SkinInfo) obj).getDisplayName());
		}
		return false;
	}

	@Override
	public int hashCode() {
		return this.getDisplayName().hashCode();
	}
}

==> radiance-substance-4.0.0-sources.jar: org/pushingpixels/substance/api/skin/SkinInfo.java <==
/*
 * Copyright (c) 2005-2021 Radiance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of the copyright holder nor the names of
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.pushingpixels.substance.api.skin;

import org.pushingpixels.substance.internal.utils.TraitInfoImpl;

/**
 * Information on a single skin. This class is part of officially supported API.
 * 
 * @author Kirill Grouchnikov
 */
public class SkinInfo extends TraitInfoImpl {
	private boolean isLookAndFeelClassNameResolved;
	private LazyClassNameResolver lookAndFeelClassNameResolver;
	private String lookAndFeelClassName;

	/**
	 * Simple constructor.
	 * 
	 * @param skinDisplayName
	 *            Display name of <code>this</code> skin.
	 * @param skinClassNameResolver
	 *            Class name resolver of <code>this</code> skin.
	 */
	public SkinInfo(String skinDisplayName, LazyClassNameResolver skinClassNameResolver,
			LazyClassNameResolver lookAndFeelClassNameResolver) {
		super(skinDisplayName, skinClassNameResolver);
		this.lookAndFeelClassNameResolver = lookAndFeelClassNameResolver;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof SkinInfo) {
			return this.getDisplayName().equals(((SkinInfo) obj).getDisplayName());
		}
		return false;
	}

	@Override
	public int hashCode() {
		return this.getDisplayName().hashCode();
	}

	public String getLookAndFeelClassName() {
		if (!this.isLookAndFeelClassNameResolved) {
			this.lookAndFeelClassName = this.lookAndFeelClassNameResolver.createClassName();
			this.isLookAndFeelClassNameResolved = true;
		}

		return this.lookAndFeelClassName;
	}
}
